==> template-oss-4.21.4.tgz: package/lib/util/template.js <==
const Handlebars = require('handlebars')
const { basename, extname, join } = require('path')
const fs = require('fs')
const DELETE = '__DELETE__'

const safeValues = (obj) => Object.entries(obj).map(([key, value]) =>
  [key, new Handlebars.SafeString(value)])

const partialName = (s) => basename(s, extname(s)) // remove extension
  .replace(/^_/, '') // remove leading underscore
  .replace(/-([a-z])/g, (_, g) => g.toUpperCase()) // camelcase

const makePartials = (dir, isBase) => {
  const partials = fs.readdirSync(dir).reduce((acc, f) => {
    const partial = fs.readFileSync(join(dir, f)).toString()
    const name = partialName(f)

    if (isBase) {
      // in the default dir, everything is a partial
      // and also gets set with a default prefix for extending
      acc[name] = partial
      acc[partialName(`default-${name}`)] = partial
    } else if (f.startsWith('_')) {
      // otherwise only _ files get set as partials
      acc[name] = partial
    }

    return acc
  }, {})

  Handlebars.registerPartial(partials)
}

const setupHandlebars = (dirs) => {
  Handlebars.registerHelper('obj', ({ hash }) => Object.fromEntries(safeValues(hash)))
  Handlebars.registerHelper('join', (arr, sep) => arr.join(typeof sep === 'string' ? sep : ', '))
  Handlebars.registerHelper('pluck', (arr, key) => arr.map(a => a[key]))
  Handlebars.registerHelper('quote', (arr) => arr.map(a => `'${a}'`))
  Handlebars.registerHelper('last', (arr) => arr[arr.length - 1])
  Handlebars.registerHelper('json', (c) => JSON.stringify(c))
  Handlebars.registerHelper('del', () => JSON.stringify(DELETE))

  if (Array.isArray(dirs)) {
    const [baseDir, ...otherDirs] = dirs
    makePartials(baseDir, true)
    for (const dir of otherDirs) {
      makePartials(dir)
    }
  }
}

const template = (str, { config = {}, ...options }) => {
  setupHandlebars(config.__PARTIAL_DIRS__)

  const t = Handlebars.compile(str, { strict: true })

  // merge in config as top level data in templates
  return t({ ...options, ...config })
}

module.exports = template
module.exports.DELETE = DELETE

==> template-oss-4.23.0.tgz: package/lib/util/template.js <==
const Handlebars = require('handlebars')
const { basename, extname, join } = require('path')
const { Range } = require('semver')
const fs = require('fs')
const DELETE = '__DELETE__'

const safeValues = obj => Object.entries(obj).map(([key, value]) => [key, new Handlebars.SafeString(value)])

const partialName = s =>
  basename(s, extname(s)) // remove extension
    .replace(/^_/, '') // remove leading underscore
    .replace(/-([a-z])/g, (_, g) => g.toUpperCase()) // camelcase

const makePartials = (dir, isBase) => {
  const partials = fs.readdirSync(dir).reduce((acc, f) => {
    const partial = fs.readFileSync(join(dir, f)).toString()
    const name = partialName(f)

    if (isBase) {
      // in the default dir, everything is a partial
      // and also gets set with a default prefix for extending
      acc[name] = partial
      acc[partialName(`default-${name}`)] = partial
    } else if (f.startsWith('_')) {
      // otherwise only _ files get set as partials
      acc[name] = partial
    }

    return acc
  }, {})

  Handlebars.registerPartial(partials)
}

const setupHandlebars = dirs => {
  Handlebars.registerHelper('obj', ({ hash }) => Object.fromEntries(safeValues(hash)))
  Handlebars.registerHelper('extGlob', arr => `{${arr.join(',')}}`)
  Handlebars.registerHelper('join', (arr, sep) => arr.join(typeof sep === 'string' ? sep : ', '))
  Handlebars.registerHelper('pluck', (arr, key) => arr.map(a => a[key]))
  Handlebars.registerHelper('quote', arr => arr.map(a => `'${a}'`))
  Handlebars.registerHelper('last', arr => arr[arr.length - 1])
  Handlebars.registerHelper('json', c => JSON.stringify(c))
  Handlebars.registerHelper('del', () => JSON.stringify(DELETE))
  Handlebars.registerHelper('semverRangeMajor', v => new Range(v).set[0][0].semver.major)
  Handlebars.registerHelper('lte', (a, b) => a <= b)

  if (Array.isArray(dirs)) {
    const [baseDir, ...otherDirs] = dirs
    makePartials(baseDir, true)
    for (const dir of otherDirs) {
      makePartials(dir)
    }
  }
}

const template = (str, { config = {}, ...options }) => {
  setupHandlebars(config.__PARTIAL_DIRS__)

  const t = Handlebars.compile(str, { strict: true })

  // merge in config as top level data in templates
  return t({ ...options, ...config })
}

module.exports = template
module.exports.DELETE = DELETE
